lefschetz_family: Computing periods of algebraic varieties using Lefschetz fibration theory
===========================================================================================

Description
-----------

This package implements algorithms relying on Lefschetz fibration theory to compute periods of algebraic varieties.

License
-------

GPLv3

Upstream Contact
----------------

https://pypi.org/project/lefschetz-family/
